==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_functions/mp7999_001/MP7999_GetWorkOrderActivityCheckListDefault_001.java <==

package net.datastream.schemas.mp_functions.mp7999_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ACTIVITYCODE;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkOrderActivityCheckListDefault" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workorderid",
    "activitycode",
    "jobsequence"
})
@XmlRootElement(name = "MP7999_GetWorkOrderActivityCheckListDefault_001")
public class MP7999_GetWorkOrderActivityCheckListDefault_001 {

    @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected WOID_Type workorderid;
    @XmlElement(name = "ACTIVITYCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected ACTIVITYCODE activitycode;
    @XmlElement(name = "JOBSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long jobsequence;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Obtient la valeur de la propriété workorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Définit la valeur de la propriété workorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

    /**
     * Obtient la valeur de la propriété activitycode.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public ACTIVITYCODE getACTIVITYCODE() {
        return activitycode;
    }

    /**
     * Définit la valeur de la propriété activitycode.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public void setACTIVITYCODE(ACTIVITYCODE value) {
        this.activitycode = value;
    }

    /**
     * Obtient la valeur de la propriété jobsequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Définit la valeur de la propriété jobsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_ORDER_ACTIVITY_CHECK_LIST_DEFAULT;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_functions/mp7999_001/MP7999_GetWorkOrderActivityCheckListDefault_001.java <==

package net.datastream.schemas.mp_functions.mp7999_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ACTIVITYCODE;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkOrderActivityCheckListDefault" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workorderid",
    "activitycode",
    "jobsequence"
})
@XmlRootElement(name = "MP7999_GetWorkOrderActivityCheckListDefault_001")
public class MP7999_GetWorkOrderActivityCheckListDefault_001 {

    @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected WOID_Type workorderid;
    @XmlElement(name = "ACTIVITYCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected ACTIVITYCODE activitycode;
    @XmlElement(name = "JOBSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long jobsequence;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the workorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Sets the value of the workorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

    /**
     * Gets the value of the activitycode property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public ACTIVITYCODE getACTIVITYCODE() {
        return activitycode;
    }

    /**
     * Sets the value of the activitycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public void setACTIVITYCODE(ACTIVITYCODE value) {
        this.activitycode = value;
    }

    /**
     * Gets the value of the jobsequence property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Sets the value of the jobsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_ORDER_ACTIVITY_CHECK_LIST_DEFAULT;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
